@@ -5,7 +5,7 @@
 NAME = "orionis"
 
 # Current version of the framework
-VERSION = "0.22.0"
+VERSION = "0.243.0"
 
 # Full name of the author or maintainer of the project
 AUTHOR = "Raul Mauricio Uñate Castro"
@@ -26,10 +26,13 @@ SKELETON = "https://github.com/orionis-framework/skeleton"
 FRAMEWORK = "https://github.com/orionis-framework/framework"
 
 # URL to the project's documentation
-DOCS = "https://github.com/orionis-framework/docs"
+DOCS = "https://orionis-framework.com/"
+
+# API URL to the project's JSON data
+API = "https://pypi.org/pypi/orionis/json"
 
 #--------------------------------------------------------------------------
 # Python Requirements
 #--------------------------------------------------------------------------
 # Minimum Python version required to run the project
-PYTHON_REQUIRES = ">=3.12"
+PYTHON_REQUIRES = ">=3.12"
\ No newline at end of file
