@@ -1,12 +1,4 @@
-from orionis.luminate.contracts.console.command_filter_interface import ICommandFilter
-
-# List of commands that should be excluded from output formatting
-EXCLUDED_COMMANDS = [
-    'schedule:work',   # Command to handle scheduled work
-    'help',            # Command to show help information
-    'version',         # Command to display version information
-    'tests:run'        # Command to run tests
-]
+from orionis.luminate.contracts.console.command_filter import ICommandFilter
 
 class CommandFilter(ICommandFilter):
     """
@@ -37,4 +29,8 @@ class CommandFilter(ICommandFilter):
         bool
             Returns True if the command is excluded from output formatting, False otherwise.
         """
-        return command in EXCLUDED_COMMANDS
+        return command in [
+            'schedule:work',   # Command to handle scheduled work
+            'help',            # Command to show help information
+            'version',         # Command to display version information
+        ]
