@@ -1,8 +1,7 @@
 from orionis.framework import VERSION
-from orionis.luminate.console.register import register
 from orionis.luminate.console.base.command import BaseCommand
+from orionis.luminate.console.exceptions.cli_runtime_error import CLIOrionisRuntimeError
 
-@register.command
 class VersionCommand(BaseCommand):
     """
     Command class to display the current version of the Orionis framework.
@@ -10,10 +9,8 @@ class VersionCommand(BaseCommand):
     This command prints the version number of the framework in use.
     """
 
-    # Command signature used for execution.
     signature = "version"
 
-    # Brief description of the command.
     description = "Prints the version of the framework in use."
 
     def handle(self) -> None:
@@ -29,11 +26,6 @@ class VersionCommand(BaseCommand):
             with the original exception message.
         """
         try:
-
-            # Print the version number
             self.textSuccessBold(f"Orionis Framework v{VERSION}")
-
         except Exception as e:
-
-            # Raise a ValueError if an unexpected error occurs.
-            raise ValueError(f"An unexpected error occurred: {e}") from e
+            raise CLIOrionisRuntimeError(f"An unexpected error occurred: {e}") from e
