@@ -1,6 +1,5 @@
-from typing import Any, Tuple
-from orionis.luminate.console.runner import CLIRunner
-from orionis.luminate.contracts.console.kernel_interface import ICLIKernel
+from typing import Any
+from orionis.luminate.contracts.console.kernel import ICLIKernel
 
 class CLIKernel(ICLIKernel):
     """
@@ -29,4 +28,4 @@ class CLIKernel(ICLIKernel):
         Any
             The result of the executed command.
         """
-        return CLIRunner.handle(None, {}, *args)
+        pass
\ No newline at end of file
